Description Usage Format Source
A data frame containing tokenized utterances of children from 14 corpora in
the CHILDES database (2018.1). This data frame is a tokenized version of the
childes_utterances data frame.
1 |
A data frame with 1,021,343 rows representing individual tokens and 7 columns:
collectiona factor denoting the CHILDES collection of the corpus
corpusa factor denoting corpus name
childa character string giving the child's name
sexa factor giving the child's sex
agea double giving the child's age
transcript_idinteger denoting the transcript ID of an utterance
tokena character string giving a token
Data is from the CHILDES Database (https://childes.talkbank.org) and is accessed using the childesr package (https://github.com/langcog/childesr).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.